package info.aspirecn.iov.sjjh.shupplier10000005.service;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.exc.UnrecognizedPropertyException;
import info.aspirecn.iov.sjjh.commons.lang.ChannelTypeHandleResponseObject;
import info.aspirecn.iov.sjjh.commons.lang.Constant;
import info.aspirecn.iov.sjjh.commons.lang.Md5Util;
import info.aspirecn.iov.sjjh.commons.lang.PatternTools;
import info.aspirecn.iov.sjjh.shupplier10000005.SjjhConstant;
import info.aspirecn.iov.sjjh.shupplier10000005.vo.*;
import info.aspirecn.iov.sjjh.shupplier10000005.vo.BankRequestJsonObject.BankCheckRequestChildObject;
import info.aspirecn.iov.sjjh.shupplier10000005.vo.RequestJsonObject.SCMIdCardCheckRequestChildObject;
import info.aspirecn.rdc.aspirecloud.node.except.utils.ErrorUtils;
import lombok.extern.slf4j.Slf4j;
import okhttp3.*;
import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import java.io.IOException;
import java.net.SocketTimeoutException;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.TimeUnit;

/**
 *
 * @author minmin
 *
 */
@Slf4j
@Service
public class Supplier10000005ServiceImpl implements Supplier10000005Service {
	/**接口返回正常码*/
	private static final int INTERFACE_RETURN_SUCCESS = 200;
	/**用来判断接口返回提示中的非移动号提示，用来单独显示错误*/
	private static final String NO_MOBILE = "非中国移动";
	/**用来判断接口返回提示中的非移动号提示，用来单独显示错误*/
	private static final String NO_LIANTONG = "非中国联通";
	/**用来判断接口返回提示中的非移动号提示，用来单独显示错误*/
	private static final String NO_DIANXIN = "非中国电信";
	/**银行卡参数格式有问题*/
	private static final String BANK_CODE_ERROR = "银行卡为空或格式不正确";
	/**查询成功提示*/
	private static final String INTERFACE_RETURN_SUCCESS_TEXT = "查询成功";

	@Value("${custom.url}")
	private String url;
	@Value("${custom.app.key}")
    private String appKey;
	@Value("${custom.secret.key}")
    private String secretKey;
	@Value("${custom.api}")
    private String api;
	@Value("${custom.yd1-api}")
    private String yd1Api;
	@Value("${custom.yd2-api}")
    private String yd2Api;
	@Value("${custom.yd3-api}")
    private String yd3Api;
	@Value("${custom.yd4-api}")
    private String yd4Api;
	@Value("${custom.dianxin-api}")
    private String dianxinApi;
	@Value("${custom.liantong-api}")
    private String liantongApi;
	@Value("${custom.yd-online-time}")
	private String ydOnlineTime;
	@Value("${custom.yd-online-status}")
    private String ydOnlineStatus;
	@Value("${custom.dx-online-time}")
	private String dxOnlineTime;
	@Value("${custom.dx-online-status}")
    private String dxOnlineStatus;
	@Value("${custom.lt-online-time}")
	private String ltOnlineTime;
	@Value("${custom.lt-online-status}")
    private String ltOnlineStatus;
	@Value("${custom.yin-hang-three}")
    private String yinHangThree;
	@Value("${custom.yin-hang-four}")
    private String yinHangFour;
	@Value("${custom.sleepTime}")
	private String sleepTime;
	@Value("${custom.decode-three-element}")
	private String decodeThreeElement;
	@Value("${custom.ctcc-detail}")
	private String ctccDetail;
	@Value("${custom.jkxyUrl}")
	private String jkxyUrl;

	private OkHttpClient okHttpClient = new OkHttpClient.Builder().build();

    @Override
    public ChannelTypeHandleResponseObject scmIdCardCheck(
    		HttpServletRequest request,String customBody,int outTime) {
    	ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
    	ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
    	String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
    	if(StringUtils.isBlank(returnType)) {
    		returnType = Constant.CUSTOMER_RETURN_ZW;
    	}

    	try {
    		if(outTime <= 0) {
	        	outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
	        }

			MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);

			RequestJsonObject requestJsonObject = new RequestJsonObject();
	        SCMIdCardCheckRequestChildObject requestChildObject = new SCMIdCardCheckRequestChildObject();
	        requestJsonObject.setApi(api);
	        requestJsonObject.setAppKey(appKey);
	        requestJsonObject.setAppSecret(secretKey);

	        log.info("scmIdCardCheck---customBody={},outTime={}",customBody,outTime);
	        ObjectMapper objectMapper = new ObjectMapper();
	        SCMIdCardCheckRequestObject requestObject = objectMapper.readValue(customBody,
	    			SCMIdCardCheckRequestObject.class);
	        String name = requestObject.getName();
	        String idCode = requestObject.getIdCode();

	        //校验参数
	        if(StringUtils.isBlank(name) || !PatternTools.checkResult(Constant.PATTERN_CN_NAME_REGEX, name)) {
	        	ret.setCode(Constant.SUCCESS);
	        	if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
	        		ret.setResultCode(Constant.NAME_FORMAT_ERROR_CODE);
	        		ret.setResultDesc(Constant.NAME_FORMAT_ERROR);
	        		ret.setResultBody(Constant.NAME_FORMAT_ERROR);
	        	} else {
	        		ret.setResultCode(Constant.JK_NAME_FORMAT_ERROR_CODE);
	        		ret.setResultDesc(Constant.JK_NAME_FORMAT_ERROR);
	        		ret.setResultBody(Constant.JK_NAME_FORMAT_ERROR);
	        	}

	        	return ret;
	        } else if(StringUtils.isBlank(idCode) || !PatternTools.checkResult(Constant.PATTERN_ID_NUMBER_REGEX, idCode)) {
	        	ret.setCode(Constant.SUCCESS);
	        	if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
	        		ret.setResultCode(Constant.IDCODE_FORMAT_ERROR_CODE);
	        		ret.setResultDesc(Constant.IDCODE_FORMAT_ERROR);
	        		ret.setResultBody(Constant.IDCODE_FORMAT_ERROR);
	        	} else {
	        		ret.setResultCode(Constant.JK_IDCODE_FORMAT_ERROR_CODE);
	        		ret.setResultDesc(Constant.JK_IDCODE_FORMAT_ERROR);
	        		ret.setResultBody(Constant.JK_IDCODE_FORMAT_ERROR);
	        	}

	        	return ret;
	        }

	        requestChildObject.setId_number(idCode);
	        requestChildObject.setName(name);
	        requestJsonObject.setData(requestChildObject);
	        String jsonStr = objectMapper.writeValueAsString(requestJsonObject);
	        log.info("三传木二要素调接口时传的参数:{}", jsonStr);

	        RequestBody requestBody = RequestBody.create(mediaType, jsonStr);
	        Request okRequest = new Request.Builder().post(requestBody).url(url).build();
	        OkHttpClient client = okHttpClient.newBuilder()
	        		.connectTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.readTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.writeTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.build();
	        Response response = client.newCall(okRequest).execute();

	        String responseContext = response.body().string();
	    	log.info("三传木身份证：{}",responseContext);
	    	SCMIdCardCheckRespnoseObject responseObject = objectMapper.readValue(responseContext,
	    			SCMIdCardCheckRespnoseObject.class);


	    	if(responseObject != null) {
	    		upstreamCode = responseObject.getCode();
	    		//code等200且data等于0或1时收费
	    		boolean resultBool = SjjhConstant.INTERFACE_RETURN_SUCCESS.equals(responseObject.getCode())
	    				&& (responseObject.getData() == SjjhConstant.INTERFACE_QUERY_IDENTICAL
						|| responseObject.getData() == SjjhConstant.INTERFACE_QUERY_NO_IDENTICAL);
	    		if(resultBool) {
	    			ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
	    		}
	    		ret.setCode(Constant.SUCCESS);

	    		//根据客户来源返回对应码
	    		getChannelTypeHandleResponseObject(returnType, ret, "", responseObject);
	    	} else {
	    		ret.setCode(Constant.FAIL);
	            ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
	    	}
    	} catch(SocketTimeoutException ste) {
        	ErrorUtils.captureException(ste);
        	ret.setCode(Constant.REQUEST_TIMEOUT);

        } catch(UnrecognizedPropertyException upe) {
			log.info("三传木身份证-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            } else {
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
        	ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch(IOException ioe) {
        	ErrorUtils.captureException(ioe);
        	ret.setCode(Constant.FAIL);

        }

    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	return ret;
    }

    @Override
    public ChannelTypeHandleResponseObject scmMobileCheck(
    		HttpServletRequest request,int type,String customBody,int outTime) {
    	ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
    	ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
    	String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
    	if(StringUtils.isBlank(returnType)) {
    		returnType = Constant.CUSTOMER_RETURN_ZW;
    	}

    	try {
    		if(outTime <= 0) {
	        	outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
	        }


    		log.info("scmMobileCheck---customBody={},outTime={}",customBody,outTime);
    		ObjectMapper objectMapper = new ObjectMapper();
	    	SCMIdCardCheckRequestObject requestObject = objectMapper.readValue(customBody,
	    			SCMIdCardCheckRequestObject.class);
	    	String name = requestObject.getName();
	        String idCode = requestObject.getIdCode();
	        String mobile = requestObject.getMobile();
	        //校验参数
			ret = returnISPThreeCheckPara( name, idCode, mobile, returnType);
	        if(StringUtils.isNotBlank(ret.getResultDesc())) {
	        	return ret;
	        }

	    	SCMIdCardCheckRequestChildObject requestChildObject = new SCMIdCardCheckRequestChildObject();
	        requestChildObject.setId_number(idCode);
	        requestChildObject.setName(name);
	        requestChildObject.setMobile(mobile);
	        String signature = Md5Util.encrypt32(secretKey +"&"+ name + "&" + idCode + "&" + mobile);
	        requestChildObject.setSign(signature.toUpperCase());


			MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
	        RequestJsonObject requestJsonObject = new RequestJsonObject();
	        String apiStr = yd2Api;
	        if(type == SjjhConstant.YI_DONG_TWO) {
	        	apiStr = yd3Api;
	        } else if(type == SjjhConstant.YI_DONG_THREE) {
	        	apiStr = yd1Api;
	        } else if(type == SjjhConstant.YI_DONG_FOUR) {
	        	apiStr = yd4Api;
	        }
	        requestJsonObject.setApi(apiStr);
	        requestJsonObject.setAppKey(appKey);
	        requestJsonObject.setAppSecret(secretKey);
	        requestJsonObject.setData(requestChildObject);
	        String jsonStr = objectMapper.writeValueAsString(requestJsonObject);
	        log.info("三传木移动三要素{}号调接口时传的参数:{}", type,jsonStr);
	        RequestBody requestBody = RequestBody.create(mediaType, jsonStr);

	        //Request okRequest = new Request.Builder().post(requestBody).url("http://10.8.18.161:8080/atp/mock/scmMobileCheck").build();
	        Request okRequest = new Request.Builder().post(requestBody).url(url).build();
	        OkHttpClient client = okHttpClient.newBuilder()
	        		.connectTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.readTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.writeTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.build();
	        Response response = client.newCall(okRequest).execute();
	        String responseContext = response.body().string();
	    	log.info("三传木移动三要素{}号调接口后的返回:{}", type, responseContext);

	    	SCMIdCardCheckRespnoseObject responseObject = objectMapper.readValue(responseContext,
	    			SCMIdCardCheckRespnoseObject.class);

	    	if(responseObject != null) {
	    		upstreamCode = responseObject.getCode();
	    		//code等200且data等于0或1时收费
	    		boolean resultBool = SjjhConstant.INTERFACE_RETURN_SUCCESS.equals(responseObject.getCode())
	    				&& (responseObject.getData() == SjjhConstant.INTERFACE_QUERY_IDENTICAL
						|| responseObject.getData() == SjjhConstant.INTERFACE_QUERY_NO_IDENTICAL);
	    		if(resultBool) {
	    	        ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
	    		}
	    		ret.setCode(Constant.SUCCESS);
	    		//根据客户来源返回对应码
	    		getChannelTypeHandleResponseObject(returnType, ret, NO_MOBILE, responseObject);
	    	}
	    } catch(SocketTimeoutException ste) {
	    	ErrorUtils.captureException(ste);
	    	ret.setCode(Constant.REQUEST_TIMEOUT);

	    } catch(UnrecognizedPropertyException upe) {
			log.info("三传木移动三要素-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            } else {
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
        	ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch(IOException ioe) {
	    	ErrorUtils.captureException(ioe);
	    	ret.setCode(Constant.FAIL);

	    }

    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	return ret;
    }

    public ChannelTypeHandleResponseObject scmDianXinOrLianTongCheck(
    		HttpServletRequest request,int type,String customBody,int outTime) {
    	ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
    	ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
    	String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
    	if(StringUtils.isBlank(returnType)) {
    		returnType = Constant.CUSTOMER_RETURN_ZW;
    	}

    	try {
    		if(outTime <= 0) {
	        	outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
	        }


    		log.info("scmDianXinOrLianTongCheck---customBody={},outTime={}",customBody,outTime);
    		ObjectMapper objectMapper = new ObjectMapper();
	    	SCMIdCardCheckRequestObject requestObject = objectMapper.readValue(customBody,
	    			SCMIdCardCheckRequestObject.class);
	    	String name = requestObject.getName();
	        String idCode = requestObject.getIdCode();
	        String mobile = requestObject.getMobile();
	        //校验参数
	        ret = returnISPThreeCheckPara( name, idCode, mobile, returnType);
	        if(StringUtils.isNotBlank(ret.getResultDesc())) {
	        	return ret;
	        }

	    	SCMIdCardCheckRequestChildObject requestChildObject = new SCMIdCardCheckRequestChildObject();
	        requestChildObject.setId_number(idCode);
	        requestChildObject.setName(name);
	        requestChildObject.setMobile(mobile);
	        String signature = Md5Util.encrypt32(secretKey +"&"+ name + "&" + idCode + "&" + mobile);
	        requestChildObject.setSign(signature.toUpperCase());


			MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
	        RequestJsonObject requestJsonObject = new RequestJsonObject();
	        String apiStr = dianxinApi;
	        String str = NO_DIANXIN;
	        //String requestUrl = "http://10.8.18.161:8080/atp/mock/scmDianXinCheck";
	        if(type == SjjhConstant.LIAN_TONG) {
	        	apiStr = liantongApi;
	        	str  = NO_LIANTONG;
	        	//requestUrl = "http://10.8.18.161:8080/atp/mock/scmLianTongCheck";
	        }
	        requestJsonObject.setApi(apiStr);
	        requestJsonObject.setAppKey(appKey);
	        requestJsonObject.setAppSecret(secretKey);
	        requestJsonObject.setData(requestChildObject);
	        String jsonStr = objectMapper.writeValueAsString(requestJsonObject);
	        log.info("三传木电信、联通三要素{}号调接口时传的参数:{}", type,jsonStr);
	        RequestBody requestBody = RequestBody.create(mediaType, jsonStr);

	        //Request okRequest = new Request.Builder().post(requestBody).url(requestUrl).build();
	        Request okRequest = new Request.Builder().post(requestBody).url(url).build();
	        OkHttpClient client = okHttpClient.newBuilder()
	        		.connectTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.readTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.writeTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.build();
	        Response response = client.newCall(okRequest).execute();
	        String responseContext = response.body().string();
	    	log.info("三传木电信、联通三要素{}号调接口后的返回:{}", type, responseContext);

	    	SCMIdCardCheckRespnoseObject responseObject = objectMapper.readValue(responseContext,
	    			SCMIdCardCheckRespnoseObject.class);

	    	if(responseObject != null) {
	    		upstreamCode = responseObject.getCode();

	    		//code等200且data等于0或1时收费
	    		boolean resultBool = SjjhConstant.INTERFACE_RETURN_SUCCESS.equals(responseObject.getCode())
	    				&& (responseObject.getData() == SjjhConstant.INTERFACE_QUERY_IDENTICAL
						|| responseObject.getData() == SjjhConstant.INTERFACE_QUERY_NO_IDENTICAL);
	    		if(resultBool) {
	    	        ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
	    		}
	    		ret.setCode(Constant.SUCCESS);

	    		//根据客户来源返回对应码
	    		getChannelTypeHandleResponseObject(returnType, ret, str, responseObject);

	    	}
	    } catch(SocketTimeoutException ste) {
	    	ErrorUtils.captureException(ste);
	    	ret.setCode(Constant.REQUEST_TIMEOUT);

	    } catch(UnrecognizedPropertyException upe) {
			log.info("三传木电信、联通三要素-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            } else {
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
        	ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch(IOException ioe) {
	    	ErrorUtils.captureException(ioe);
	    	ret.setCode(Constant.FAIL);

	    }

    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	return ret;
    }

    @Override
    public ChannelTypeHandleResponseObject scmMobileOnlineTimeCheck(
    		HttpServletRequest request,String customBody,int outTime) {
    	ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
    	ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
    	String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
    	if(StringUtils.isBlank(returnType)) {
    		returnType = Constant.CUSTOMER_RETURN_ZW;
    	}

    	try {
    		if(outTime <= 0) {
	        	outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
	        }


    		log.info("scmMobileOnlineTimeCheck---customBody={},outTime={}",customBody,outTime);
    		ObjectMapper objectMapper = new ObjectMapper();
	    	SCMIdCardCheckRequestObject requestObject = objectMapper.readValue(customBody,
	    			SCMIdCardCheckRequestObject.class);
	        String mobile = requestObject.getMobile();
	        //校验参数
	        ret = returnMobileCheckPara(ret, mobile, returnType);
	        if(StringUtils.isNotBlank(ret.getResultDesc())) {
	        	return ret;
	        }

	    	SCMIdCardCheckRequestChildObject requestChildObject = new SCMIdCardCheckRequestChildObject();
	        requestChildObject.setMobile(mobile);
	        String signature = Md5Util.encrypt32(secretKey + "&" + mobile);
	        requestChildObject.setSign(signature.toUpperCase());


			MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
	        RequestJsonObject requestJsonObject = new RequestJsonObject();

	        requestJsonObject.setApi(ydOnlineTime);
	        requestJsonObject.setAppKey(appKey);
	        requestJsonObject.setAppSecret(secretKey);
	        requestJsonObject.setData(requestChildObject);
	        String jsonStr = objectMapper.writeValueAsString(requestJsonObject);
	        log.info("调三传木移动在网时长接口时传的参数:{}", jsonStr);
	        RequestBody requestBody = RequestBody.create(mediaType, jsonStr);

	        //Request okRequest = new Request.Builder().post(requestBody).url("http://10.8.18.161:8080/atp/mock/scmMobileOnlineTimeCheck").build();
	        Request okRequest = new Request.Builder().post(requestBody).url(url).build();
	        OkHttpClient client = okHttpClient.newBuilder()
	        		.connectTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.readTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.writeTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.build();
	        Response response = client.newCall(okRequest).execute();
	        String responseContext = response.body().string();
	    	log.info("调三传木移动在网时长接口后的返回:{}", responseContext);

	    	JSONObject jsonObject = JSONObject.parseObject(responseContext);
	    	log.info("三传木移动在网时长jsonObject={}",jsonObject);
	    	//上游返回码
	    	Integer returnCode = (Integer)jsonObject.get("code");
	    	if(returnCode != null) {
	    		upstreamCode = "" + returnCode;
	    	}

	    	ret = getOnlineTimeCode( ret, jsonObject, returnCode, returnType);

	    } catch(SocketTimeoutException ste) {
	    	ErrorUtils.captureException(ste);
	    	ret.setCode(Constant.REQUEST_TIMEOUT);
	    } catch(UnrecognizedPropertyException upe) {
			log.info("三传木移动在网时长-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            } else {
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
        	ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch(IOException ioe) {
	    	ErrorUtils.captureException(ioe);
	    	ret.setCode(Constant.FAIL);
	    }

    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	return ret;
    }

    @Override
    public ChannelTypeHandleResponseObject scmMobileOnlineStatusCheck(
    		HttpServletRequest request,String customBody,int outTime) {
    	ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
    	ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
    	String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
    	if(StringUtils.isBlank(returnType)) {
    		returnType = Constant.CUSTOMER_RETURN_ZW;
    	}

    	Response response = null;
    	String responseContext = "";
    	try {
    		if(outTime <= 0) {
	        	outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
	        }


    		log.info("scmMobileOnlineStatusCheck---customBody={},outTime={}",customBody,outTime);
    		ObjectMapper objectMapper = new ObjectMapper();
	    	SCMIdCardCheckRequestObject requestObject = objectMapper.readValue(customBody,
	    			SCMIdCardCheckRequestObject.class);
	        String mobile = requestObject.getMobile();
	        //校验参数
	        ret = returnMobileCheckPara(ret, mobile, returnType);
	        if(StringUtils.isNotBlank(ret.getResultDesc())) {
	        	return ret;
	        }

	    	SCMIdCardCheckRequestChildObject requestChildObject = new SCMIdCardCheckRequestChildObject();
	        requestChildObject.setMobile(mobile);
	        String signature = Md5Util.encrypt32(secretKey + "&" + mobile);
	        requestChildObject.setSign(signature.toUpperCase());


			MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
	        RequestJsonObject requestJsonObject = new RequestJsonObject();

	        requestJsonObject.setApi(ydOnlineStatus);
	        requestJsonObject.setAppKey(appKey);
	        requestJsonObject.setAppSecret(secretKey);
	        requestJsonObject.setData(requestChildObject);
	        String jsonStr = objectMapper.writeValueAsString(requestJsonObject);
	        log.info("调三传木移动在网状态接口时传的参数:{}", jsonStr);
	        RequestBody requestBody = RequestBody.create(mediaType, jsonStr);

	        //Request okRequest = new Request.Builder().post(requestBody).url("http://10.8.18.161:8080/atp/mock/scmMobileOnlineStatusCheck").build();
	        Request okRequest = new Request.Builder().post(requestBody).url(url).build();
	        OkHttpClient client = okHttpClient.newBuilder()
	        		.connectTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.readTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.writeTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.build();
	        response = client.newCall(okRequest).execute();
	        responseContext = response.body().string();
	    	log.info("调三传木移动在网状态接口后的返回:{}", responseContext);

	    	JSONObject jsonObject = JSONObject.parseObject(responseContext);

	    	Integer returnCode = (Integer)jsonObject.get("code");
	    	if(returnCode != null) {
	    		upstreamCode = "" + returnCode;
	    	}

        	ret = getOnlineStatusCode( ret, jsonObject, returnCode, returnType);


    	} catch(SocketTimeoutException ste) {
	    	ErrorUtils.captureException(ste);
	    	ret.setCode(Constant.REQUEST_TIMEOUT);

	    } catch(UnrecognizedPropertyException upe) {
			log.info("调三传木移动在网状态接口-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            } else {
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
        	ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch(IOException ioe) {
	    	ErrorUtils.captureException(ioe);
	    	ret.setCode(Constant.FAIL);

	    }

    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	return ret;
    }

    /**
     * 根据客户不同，返回对应码
     * @param returnType
     * @param ret
     * @param str  用来判断手机号段是否正确
     * @param responseObject
     * @return
     */
    private ChannelTypeHandleResponseObject getChannelTypeHandleResponseObject(
    		String returnType,
    		ChannelTypeHandleResponseObject ret,String str,
    		SCMIdCardCheckRespnoseObject responseObject) {
    	if(SjjhConstant.INTERFACE_RETURN_SUCCESS.equals(responseObject.getCode())
				&& responseObject.getData() == SjjhConstant.INTERFACE_QUERY_IDENTICAL) {
			//匹配
    		if("1".equals(returnType)) {
    			ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
    		} else {
    			ret.setResultCode(Constant.MATCH_CODE);
    		}
			ret.setResultBody(Constant.MATCH);
			ret.setResultDesc(Constant.MATCH);
		} else if(SjjhConstant.INTERFACE_QUERY_NO_IDENTICAL == responseObject.getData()) {
			//不匹配
			if("1".equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_NO_MATCH);
			} else {
    			ret.setResultCode(Constant.UN_MATCH_CODE);
    		}
			ret.setResultBody(Constant.UN_MATCH);
			ret.setResultDesc(Constant.UN_MATCH);
		} else if(SjjhConstant.NO_FIND == responseObject.getData() ) {
			//未找到
			if("1".equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
			} else {
				ret.setResultCode(Constant.UN_FIND_NUM_CODE);
			}
			ret.setResultBody(Constant.UN_FIND_NUM);
			ret.setResultDesc(Constant.UN_FIND_NUM);
		} else if(SjjhConstant.OTHER_ERROR == responseObject.getData()
				&& StringUtils.isNotBlank(str)
				&& responseObject.getMsg().indexOf(str) > -1) {
			//号段不对
			if("1".equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_NUMBER_UNMATCH);
			} else {
				ret.setResultCode(Constant.PARAGRAPH_NUMBER_UNMATCH_CODE);
			}
			ret.setResultBody(Constant.PARAGRAPH_NUMBER_UNMATCH);
			ret.setResultDesc(Constant.PARAGRAPH_NUMBER_UNMATCH);
		} else {
			//其他错误
			if("1".equals(returnType)) {
				ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
			} else {
				ret.setResultCode(Constant.OTHER_ERROR_CODE);
			}
			ret.setResultBody(Constant.OTHER_ERROR);
			ret.setResultDesc(Constant.OTHER_ERROR);
		}


    	return ret;
    }

    /**
	 * 三传木电信在网时长接口
	 * @param request
	 * @param customBody
	 * @param outTime
	 * @return
	 */
	public ChannelTypeHandleResponseObject scmDianXinOnlineTimeCheck(
			HttpServletRequest request,String customBody,int outTime) {
		ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
		ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
    	String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
    	if(StringUtils.isBlank(returnType)) {
    		returnType = Constant.CUSTOMER_RETURN_ZW;
    	}

    	try {
    		if(outTime <= 0) {
	        	outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
	        }


    		log.info("scmDianXinOnlineTimeCheck---customBody={},outTime={}",customBody,outTime);
    		ObjectMapper objectMapper = new ObjectMapper();
	    	SCMIdCardCheckRequestObject requestObject = objectMapper.readValue(customBody,
	    			SCMIdCardCheckRequestObject.class);
	        String mobile = requestObject.getMobile();
	        //校验参数
	        ret = returnMobileCheckPara(ret, mobile, returnType);
	        if(StringUtils.isNotBlank(ret.getResultDesc())) {
	        	return ret;
	        }

	    	SCMIdCardCheckRequestChildObject requestChildObject = new SCMIdCardCheckRequestChildObject();
	        requestChildObject.setMobile(mobile);
	        String signature = Md5Util.encrypt32(secretKey + "&" + mobile);
	        requestChildObject.setSign(signature.toUpperCase());


			MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
	        RequestJsonObject requestJsonObject = new RequestJsonObject();

	        requestJsonObject.setApi(dxOnlineTime);
	        requestJsonObject.setAppKey(appKey);
	        requestJsonObject.setAppSecret(secretKey);
	        requestJsonObject.setData(requestChildObject);
	        String jsonStr = objectMapper.writeValueAsString(requestJsonObject);
	        log.info("调三传木电信在网时长接口时传的参数:{}", jsonStr);
	        RequestBody requestBody = RequestBody.create(mediaType, jsonStr);

	        //Request okRequest = new Request.Builder().post(requestBody).url("http://10.8.18.161:8080/atp/mock/scmDianXinOnlineTimeCheck").build();
	        Request okRequest = new Request.Builder().post(requestBody).url(url).build();
	        OkHttpClient client = okHttpClient.newBuilder()
	        		.connectTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.readTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.writeTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.build();
	        Response response = client.newCall(okRequest).execute();
	        String responseContext = response.body().string();
	    	log.info("调三传木电信在网时长接口后的返回:{}", responseContext);

	    	JSONObject jsonObject = JSONObject.parseObject(responseContext);
	    	log.info("三传木电信在网时长jsonObject={}",jsonObject);
	    	//上游返回码
	    	Integer returnCode = (Integer)jsonObject.get("code");
	    	if(returnCode != null) {
	    		upstreamCode = "" + returnCode;
	    	}

	    	ret = getOnlineTimeCode( ret, jsonObject, returnCode, returnType);

	    } catch(SocketTimeoutException ste) {
	    	ErrorUtils.captureException(ste);
	    	ret.setCode(Constant.REQUEST_TIMEOUT);

	    } catch(UnrecognizedPropertyException upe) {
			log.info("三传木电信在网时长-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            } else {
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
        	ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch(IOException ioe) {
	    	ErrorUtils.captureException(ioe);
	    	ret.setCode(Constant.FAIL);

	    }

    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	return ret;
	}

	/**
	 * 三传木电信在网状态接口
	 * @param request
	 * @param customBody
	 * @param outTime
	 * @return
	 */
	public ChannelTypeHandleResponseObject scmDianXinOnlineStatusCheck(
			HttpServletRequest request,String customBody,int outTime) {
		ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
		ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
    	String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
    	if(StringUtils.isBlank(returnType)) {
    		returnType = Constant.CUSTOMER_RETURN_ZW;
    	}

    	Response response = null;
    	String responseContext = "";
    	try {
    		if(outTime <= 0) {
	        	outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
	        }


    		log.info("scmDianXinOnlineStatusCheck---customBody={},outTime={}",customBody,outTime);
    		ObjectMapper objectMapper = new ObjectMapper();
	    	SCMIdCardCheckRequestObject requestObject = objectMapper.readValue(customBody,
	    			SCMIdCardCheckRequestObject.class);
	        String mobile = requestObject.getMobile();
	        //校验参数
	        ret = returnMobileCheckPara(ret, mobile, returnType);
	        if(StringUtils.isNotBlank(ret.getResultDesc())) {
	        	return ret;
	        }

	    	SCMIdCardCheckRequestChildObject requestChildObject = new SCMIdCardCheckRequestChildObject();
	        requestChildObject.setMobile(mobile);
	        String signature = Md5Util.encrypt32(secretKey + "&" + mobile);
	        requestChildObject.setSign(signature.toUpperCase());


			MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
	        RequestJsonObject requestJsonObject = new RequestJsonObject();

	        requestJsonObject.setApi(dxOnlineStatus);
	        requestJsonObject.setAppKey(appKey);
	        requestJsonObject.setAppSecret(secretKey);
	        requestJsonObject.setData(requestChildObject);
	        String jsonStr = objectMapper.writeValueAsString(requestJsonObject);
	        log.info("调三传木电信在网状态接口时传的参数:{}", jsonStr);
	        RequestBody requestBody = RequestBody.create(mediaType, jsonStr);

	        //Request okRequest = new Request.Builder().post(requestBody).url("http://10.8.18.161:8080/atp/mock/DianXinOnlineStatusCheck").build();
	        Request okRequest = new Request.Builder().post(requestBody).url(url).build();
	        OkHttpClient client = okHttpClient.newBuilder()
	        		.connectTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.readTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.writeTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.build();
	        response = client.newCall(okRequest).execute();
	        responseContext = response.body().string();
	    	log.info("调三传木电信在网状态接口后的返回:{}", responseContext);

	    	JSONObject jsonObject = JSONObject.parseObject(responseContext);

	    	Integer returnCode = (Integer)jsonObject.get("code");
	    	if(returnCode != null) {
	    		upstreamCode = "" + returnCode;
	    	}

        	ret = getOnlineStatusCode( ret, jsonObject, returnCode, returnType);


    	} catch(SocketTimeoutException ste) {
	    	ErrorUtils.captureException(ste);
	    	ret.setCode(Constant.REQUEST_TIMEOUT);
	    } catch(UnrecognizedPropertyException upe) {
			log.info("三传木电信在网状态接口-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            } else {
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
        	ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch(IOException ioe) {
	    	ErrorUtils.captureException(ioe);
	    	ret.setCode(Constant.FAIL);
	    }

    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	return ret;
	}

	/**
	 * 三传木联通在网时长接口
	 * @param request
	 * @param customBody
	 * @param outTime
	 * @return
	 */
	public ChannelTypeHandleResponseObject scmLianTongOnlineTimeCheck(
			HttpServletRequest request,String customBody,int outTime) {
		ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
		ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
    	String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
    	if(StringUtils.isBlank(returnType)) {
    		returnType = Constant.CUSTOMER_RETURN_ZW;
    	}

    	try {
    		if(outTime <= 0) {
	        	outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
	        }


    		log.info("scmLianTongOnlineTimeCheck---customBody={},outTime={}",customBody,outTime);
    		ObjectMapper objectMapper = new ObjectMapper();
	    	SCMIdCardCheckRequestObject requestObject = objectMapper.readValue(customBody,
	    			SCMIdCardCheckRequestObject.class);
	        String mobile = requestObject.getMobile();
	        //校验参数
	        ret = returnMobileCheckPara(ret, mobile, returnType);
	        if(StringUtils.isNotBlank(ret.getResultDesc())) {
	        	return ret;
	        }

	    	SCMIdCardCheckRequestChildObject requestChildObject = new SCMIdCardCheckRequestChildObject();
	        requestChildObject.setMobile(mobile);
	        String signature = Md5Util.encrypt32(secretKey + "&" + mobile);
	        requestChildObject.setSign(signature.toUpperCase());


			MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
	        RequestJsonObject requestJsonObject = new RequestJsonObject();

	        requestJsonObject.setApi(ltOnlineTime);
	        requestJsonObject.setAppKey(appKey);
	        requestJsonObject.setAppSecret(secretKey);
	        requestJsonObject.setData(requestChildObject);
	        String jsonStr = objectMapper.writeValueAsString(requestJsonObject);
	        log.info("调三传木联通在网时长接口时传的参数:{}", jsonStr);
	        RequestBody requestBody = RequestBody.create(mediaType, jsonStr);

	        //Request okRequest = new Request.Builder().post(requestBody).url("http://10.8.18.161:8080/atp/mock/scmLianTongOnlineTimeCheck").build();
	        Request okRequest = new Request.Builder().post(requestBody).url(url).build();
	        OkHttpClient client = okHttpClient.newBuilder()
	        		.connectTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.readTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.writeTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.build();
	        Response response = client.newCall(okRequest).execute();
	        String responseContext = response.body().string();
	    	log.info("调三传木联通在网时长接口后的返回:{}", responseContext);

	    	JSONObject jsonObject = JSONObject.parseObject(responseContext);
	    	log.info("三传木联通在网时长jsonObject={}",jsonObject);

	    	//上游返回码
	    	Integer returnCode = (Integer)jsonObject.get("code");
	    	if(returnCode != null) {
	    		upstreamCode = "" + returnCode;
	    	}

	    	ret = getOnlineTimeCode( ret, jsonObject, returnCode, returnType);

	    } catch(SocketTimeoutException ste) {
	    	ErrorUtils.captureException(ste);
	    	ret.setCode(Constant.REQUEST_TIMEOUT);
	    } catch(UnrecognizedPropertyException upe) {
			log.info("三传木联通在网时长-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            } else {
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
        	ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch(IOException ioe) {
	    	ErrorUtils.captureException(ioe);
	    	ret.setCode(Constant.FAIL);
	    }

    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	return ret;
	}

	/**
	 * 三传木联通在网状态接口
	 * @param request
	 * @param customBody
	 * @param outTime
	 * @return
	 */
	public ChannelTypeHandleResponseObject scmLianTongOnlineStatusCheck(
			HttpServletRequest request,String customBody,int outTime) {
		ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
		ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
    	String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
    	if(StringUtils.isBlank(returnType)) {
    		returnType = Constant.CUSTOMER_RETURN_ZW;
    	}

    	Response response = null;
    	String responseContext = "";
    	try {
    		if(outTime <= 0) {
	        	outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
	        }


    		log.info("scmLianTongOnlineStatusCheck---customBody={},outTime={}",customBody,outTime);
    		ObjectMapper objectMapper = new ObjectMapper();
	    	SCMIdCardCheckRequestObject requestObject = objectMapper.readValue(customBody,
	    			SCMIdCardCheckRequestObject.class);
	        String mobile = requestObject.getMobile();
	        //校验参数
			ret = returnMobileCheckPara(ret, mobile, returnType);
	        if(StringUtils.isNotBlank(ret.getResultDesc())) {
	        	return ret;
	        }

	    	SCMIdCardCheckRequestChildObject requestChildObject = new SCMIdCardCheckRequestChildObject();
	        requestChildObject.setMobile(mobile);
	        String signature = Md5Util.encrypt32(secretKey + "&" + mobile);
	        requestChildObject.setSign(signature.toUpperCase());


			MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
	        RequestJsonObject requestJsonObject = new RequestJsonObject();

	        requestJsonObject.setApi(ltOnlineStatus);
	        requestJsonObject.setAppKey(appKey);
	        requestJsonObject.setAppSecret(secretKey);
	        requestJsonObject.setData(requestChildObject);
	        String jsonStr = objectMapper.writeValueAsString(requestJsonObject);
	        log.info("调三传木联通在网状态接口时传的参数:{}", jsonStr);
	        RequestBody requestBody = RequestBody.create(mediaType, jsonStr);

	        //Request okRequest = new Request.Builder().post(requestBody).url("http://10.8.18.161:8080/atp/mock/scmLianTongOnlineStatusCheck").build();
	        Request okRequest = new Request.Builder().post(requestBody).url(url).build();
	        OkHttpClient client = okHttpClient.newBuilder()
	        		.connectTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.readTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.writeTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.build();
	        response = client.newCall(okRequest).execute();
	        responseContext = response.body().string();
	    	log.info("调三传木联通在网状态接口后的返回:{}", responseContext);
	    	JSONObject jsonObject = JSONObject.parseObject(responseContext);

	    	Integer returnCode = (Integer)jsonObject.get("code");
	    	if(returnCode != null) {
	    		upstreamCode = "" + returnCode;
	    	}

        	ret = getOnlineStatusCode( ret, jsonObject, returnCode, returnType);

    	} catch(SocketTimeoutException ste) {
	    	ErrorUtils.captureException(ste);
	    	ret.setCode(Constant.REQUEST_TIMEOUT);
	    } catch(UnrecognizedPropertyException upe) {
			log.info("三传木联通在网状态-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            } else {
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
        	ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch(IOException ioe) {
	    	ErrorUtils.captureException(ioe);
	    	ret.setCode(Constant.FAIL);
	    }

    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	return ret;

	}

	@Override
	public ChannelTypeHandleResponseObject scmBankThreeCheck(HttpServletRequest request,String customBody,int outTime) {
		ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
		ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
    	String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
    	if(StringUtils.isBlank(returnType)) {
    		returnType = Constant.CUSTOMER_RETURN_ZW;
    	}

    	Response response = null;
    	String responseContext = "";
    	try {
    		if(outTime <= 0) {
	        	outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
	        }


    		log.info("scmBankThreeCheck---customBody={},outTime={}",customBody,outTime);
    		ObjectMapper objectMapper = new ObjectMapper();
    		SCMBankCheckRequestObject requestObject = objectMapper.readValue(customBody,
    				SCMBankCheckRequestObject.class);
	        String name = requestObject.getName();
	        String idCode = requestObject.getIdCode();
	        String bankCode = requestObject.getBankCode();
	        //校验参数
			ret = returnBankThreeCheckPara(ret, name, idCode, bankCode, returnType);
	        if(StringUtils.isNotBlank(ret.getResultDesc())) {
	        	return ret;
	        }


	        BankCheckRequestChildObject requestChildObject = new BankCheckRequestChildObject();
	        requestChildObject.setBank_card_number(bankCode);
	        requestChildObject.setName(name);
	        requestChildObject.setId_number(idCode);
	        String signature = Md5Util.encrypt32(secretKey +"&"+ bankCode + "&" + idCode + "&" + name);
	        requestChildObject.setSign(signature.toUpperCase());


			MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
			BankRequestJsonObject requestJsonObject = new BankRequestJsonObject();

	        requestJsonObject.setApi(yinHangThree);
	        requestJsonObject.setAppKey(appKey);
	        requestJsonObject.setAppSecret(secretKey);
	        requestJsonObject.setData(requestChildObject);
	        String jsonStr = objectMapper.writeValueAsString(requestJsonObject);
	        log.info("调三传木银行卡三要素接口时传的参数:{}", jsonStr);
	        RequestBody requestBody = RequestBody.create(mediaType, jsonStr);

	        Request okRequest = new Request.Builder().post(requestBody).url(url).build();
	        OkHttpClient client = okHttpClient.newBuilder()
	        		.connectTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.readTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.writeTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.build();
	        response = client.newCall(okRequest).execute();
	        responseContext = response.body().string();
	    	log.info("调三传木银行卡三要素接口后的返回:{}", responseContext);
	    	JSONObject jsonObject = JSONObject.parseObject(responseContext);

	    	if(jsonObject.getInteger("code") != null) {
	    		upstreamCode = jsonObject.getInteger("code").toString();
	    	}
	    	ret = getChannelTypeHandleResponseObjectForBank(
	        		 returnType, ret, jsonObject);

    	} catch(SocketTimeoutException ste) {
	    	ErrorUtils.captureException(ste);
	    	ret.setCode(Constant.REQUEST_TIMEOUT);
	    } catch(UnrecognizedPropertyException upe) {
			log.info("三传木银行卡三要素-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            } else {
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
        	ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch(IOException ioe) {
	    	ErrorUtils.captureException(ioe);
	    	ret.setCode(Constant.FAIL);
	    }

    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	return ret;
	}

	@Override
	public ChannelTypeHandleResponseObject scmBankFourCheck(HttpServletRequest request,String customBody,int outTime) {
		ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
		ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
    	String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
    	if(StringUtils.isBlank(returnType)) {
    		returnType = Constant.CUSTOMER_RETURN_ZW;
    	}

    	Response response = null;
    	String responseContext = "";
    	try {
    		if(outTime <= 0) {
	        	outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
	        }


    		log.info("scmBankFourCheck---customBody={},outTime={}",customBody,outTime);
    		ObjectMapper objectMapper = new ObjectMapper();
    		SCMBankCheckRequestObject requestObject = objectMapper.readValue(customBody,
    				SCMBankCheckRequestObject.class);
	        String name = requestObject.getName();
	        String idCode = requestObject.getIdCode();
	        String bankCode = requestObject.getBankCode();
	        String mobile = requestObject.getMobile();
	        //校验参数
			ret = returnBankFourCheckPara(ret, name, idCode, mobile, bankCode, returnType);
	        if(StringUtils.isNotBlank(ret.getResultDesc())) {
	        	return ret;
	        }


	        BankCheckRequestChildObject requestChildObject = new BankCheckRequestChildObject();
	        requestChildObject.setBank_card_number(bankCode);
	        requestChildObject.setName(name);
	        requestChildObject.setId_number(idCode);
	        requestChildObject.setMobile(mobile);
	        String signature = Md5Util.encrypt32(secretKey +"&"+ name + "&" + idCode + "&" + bankCode + "&" + mobile);
	        requestChildObject.setSign(signature.toUpperCase());


			MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
			BankRequestJsonObject requestJsonObject = new BankRequestJsonObject();

	        requestJsonObject.setApi(yinHangFour);
	        requestJsonObject.setAppKey(appKey);
	        requestJsonObject.setAppSecret(secretKey);
	        requestJsonObject.setData(requestChildObject);
	        String jsonStr = objectMapper.writeValueAsString(requestJsonObject);
	        log.info("调三传木银行卡四要素接口时传的参数:{}", jsonStr);
	        RequestBody requestBody = RequestBody.create(mediaType, jsonStr);

	        Request okRequest = new Request.Builder().post(requestBody).url(url).build();
	        OkHttpClient client = okHttpClient.newBuilder()
	        		.connectTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.readTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.writeTimeout(outTime, TimeUnit.MILLISECONDS)
	    			.build();
	        response = client.newCall(okRequest).execute();
	        responseContext = response.body().string();
	    	log.info("调三传木银行卡四要素接口后的返回:{}", responseContext);
	    	JSONObject jsonObject = JSONObject.parseObject(responseContext);

	    	if(jsonObject.getInteger("code") != null) {
	    		upstreamCode = jsonObject.getInteger("code").toString();
	    	}
	    	ret = getChannelTypeHandleResponseObjectForBank(
	    			returnType, ret, jsonObject);

    	} catch(SocketTimeoutException ste) {
	    	ErrorUtils.captureException(ste);
	    	ret.setCode(Constant.REQUEST_TIMEOUT);
	    } catch(UnrecognizedPropertyException upe) {
			log.info("调三传木银行卡四要素-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
            	ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            } else {
            	ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
        	ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
		} catch(IOException ioe) {
	    	ErrorUtils.captureException(ioe);
	    	ret.setCode(Constant.FAIL);
	    }

    	request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
    	return ret;
	}

	/**
	 * 返回在三网在网时长
	 * @param ret
	 * @param jsonObject
	 * @param responseContext
	 * @param returnCode
	 * @param returnType
	 * @return
	 */
	private ChannelTypeHandleResponseObject getOnlineTimeCode(ChannelTypeHandleResponseObject ret,
			JSONObject jsonObject,Integer returnCode,String returnType) {
    	Integer returnData = (Integer)jsonObject.get("data");
		//code等200且data等于1时收费
		boolean bool = INTERFACE_RETURN_SUCCESS == returnCode
				&& returnData != null
				&& SjjhConstant.INTERFACE_QUERY_IDENTICAL == returnData;

		//返回结果：{"data":1,"code":200,"msg":"{"min":"24","max":"-1"}"}
		if(bool) {
	        ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
		}
		ret.setCode(Constant.SUCCESS);

		//根据客户来源返回对应码
    	if(StringUtils.isBlank(returnType)) {
    		returnType = Constant.CUSTOMER_RETURN_ZW;
    	}

    	Object msg = jsonObject.get("msg");
		if(SjjhConstant.INTERFACE_QUERY_IDENTICAL == returnData) {
			//当手机号是非移动号时，msg的内容不是json串，而是一个普通字符串
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				if(msg instanceof String) {
					String tempStr = msg.toString();
					tempStr = tempStr.replace("min", "minimum");
					tempStr = tempStr.replace("max", "maximum");
					ret.setResultBody(tempStr);
				} else {
					JSONObject msgObject = (JSONObject)msg;
					String minimum = msgObject.getString("min");
					String maximum = msgObject.getString("max");
					JSONObject tempJsonObject = new JSONObject();
					tempJsonObject.put("minimum", minimum);
					tempJsonObject.put("maximum", maximum);
					ret.setResultBody(tempJsonObject.toJSONString());
				}
				ret.setResultCode(Constant.MATCH_CODE);
			} else {
				if(msg instanceof String) {
					ret.setResultBody(msg.toString());
				} else {
					JSONObject msgObject = (JSONObject)msg;
					ret.setResultBody(msgObject.toJSONString());
				}
				ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
			}

    		ret.setResultDesc(INTERFACE_RETURN_SUCCESS_TEXT);
		} else if(SjjhConstant.NO_FIND == returnData) {
			//未找到
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.UN_FIND_NUM_CODE);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
			}
			ret.setResultBody(Constant.NO_QUERY_INFO);
			ret.setResultDesc(Constant.NO_QUERY_INFO);
		} else if(SjjhConstant.OTHER_ERROR == returnData && msg.toString().indexOf(NO_MOBILE) > -1) {
			//号段不对
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.PARAGRAPH_NUMBER_UNMATCH_CODE);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_NUMBER_UNMATCH);
			}
			ret.setResultBody(Constant.PARAGRAPH_NUMBER_UNMATCH);
			ret.setResultDesc(Constant.PARAGRAPH_NUMBER_UNMATCH);
		} else {
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.OTHER_ERROR_CODE);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
			}
			ret.setResultBody(msg);
			ret.setResultDesc(msg.toString());
		}

		return ret;
	}

	/**
	 * 返回在三网在网状态
	 * @param ret
	 * @param jsonObject
	 * @param responseContext
	 * @param returnCode
	 * @param returnType
	 * @return
	 */
	private ChannelTypeHandleResponseObject getOnlineStatusCode(ChannelTypeHandleResponseObject ret,
			JSONObject jsonObject,Integer returnCode,String returnType) {
    	Integer returnData = (Integer)jsonObject.get("data");
    	Object msg = jsonObject.get("msg");

		//code等200且data等于1时收费
		boolean bool = INTERFACE_RETURN_SUCCESS == returnCode
				&& returnData != null
				&& SjjhConstant.INTERFACE_QUERY_IDENTICAL == returnData;

		if(bool) {
	        ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
		}
		ret.setCode(Constant.SUCCESS);

		//根据客户来源返回对应码
    	if(StringUtils.isBlank(returnType)) {
    		returnType = Constant.CUSTOMER_RETURN_ZW;
    	}

		//status: 移动1-->正常  2-->停机  3-->在网但不可用4-->销号/未启用5-->预销号6-->异常（号码状态异常）
		if(INTERFACE_RETURN_SUCCESS == returnCode
				&& SjjhConstant.INTERFACE_QUERY_IDENTICAL == returnData ) {
			//查到
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.MATCH_CODE);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
			}

			if(msg instanceof String) {
				ret.setResultBody(msg.toString());
			} else {
				JSONObject msgObject = (JSONObject)msg;
				ret.setResultBody(msgObject.toJSONString());
			}
			ret.setResultDesc(INTERFACE_RETURN_SUCCESS_TEXT);
		} else if(INTERFACE_RETURN_SUCCESS == returnCode
				&& SjjhConstant.NO_FIND == returnData) {
			//未查到
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.UN_FIND_NUM_CODE);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
			}
			ret.setResultBody(Constant.UN_FIND_NUM);
			ret.setResultDesc(Constant.UN_FIND_NUM);
		} else if(INTERFACE_RETURN_SUCCESS == returnCode
				&&  3 == returnData
				&& msg.toString().indexOf(NO_MOBILE) > -1) {
			//号段不对
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.PARAGRAPH_NUMBER_UNMATCH_CODE);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_NUMBER_UNMATCH);
			}
			ret.setResultBody(Constant.PARAGRAPH_NUMBER_UNMATCH);
			ret.setResultDesc(Constant.PARAGRAPH_NUMBER_UNMATCH);
		} else {
			//其他错误
			if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.OTHER_ERROR_CODE);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
			}
			ret.setResultBody(msg);
			ret.setResultDesc(msg.toString());
		}

		return ret;
	}

	 /**
     * 银行卡返回码：根据客户不同，返回对应码
     * @param returnType
     * @param ret
     * @param str  用来判断手机号段是否正确
     * @param responseObject
     * @return
     */
    private ChannelTypeHandleResponseObject getChannelTypeHandleResponseObjectForBank(
    		String returnType,ChannelTypeHandleResponseObject ret,
    		JSONObject jsonObject) {
    	ret.setCode(Constant.SUCCESS);

    	Integer code = jsonObject.getInteger("code");
    	Integer data = jsonObject.getInteger("data");
    	if("1".equals(returnType)) {
	    	if(SjjhConstant.INTERFACE_RETURN_SUCCESS.equals(code+"")
					&& data == SjjhConstant.INTERFACE_QUERY_IDENTICAL) {
				//匹配
				ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
				ret.setResultBody(Constant.MATCH);
				ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
				ret.setResultDesc(Constant.MATCH);
			} else if(SjjhConstant.INTERFACE_RETURN_SUCCESS.equals(code+"")
					&& SjjhConstant.INTERFACE_QUERY_NO_IDENTICAL == data) {
				//不匹配
				ret.setResultCode(Constant.JK_RETURN_CODE_NO_MATCH);
				ret.setResultBody(Constant.UN_MATCH);
				ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
				ret.setResultDesc(Constant.UN_MATCH);
			} else if(SjjhConstant.INTERFACE_RETURN_SUCCESS.equals(code+"")
					&& SjjhConstant.NO_FIND == data ) {
				//未找到
				ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
				ret.setResultBody(Constant.UN_FIND_NUM);
				ret.setResultDesc(Constant.UN_FIND_NUM);
			} else {
				//其他错误
				ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
				ret.setResultBody(Constant.OTHER_ERROR);
				ret.setResultDesc(Constant.OTHER_ERROR);
			}
    	} else {
    		if(SjjhConstant.INTERFACE_RETURN_SUCCESS.equals(code+"")
					&& SjjhConstant.INTERFACE_QUERY_IDENTICAL == data) {
				//匹配
				ret.setResultCode(Constant.MATCH_CODE);
				ret.setResultBody(Constant.MATCH);
				ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
				ret.setResultDesc(Constant.MATCH);
			} else if(SjjhConstant.INTERFACE_RETURN_SUCCESS.equals(code+"")
					&& SjjhConstant.INTERFACE_QUERY_NO_IDENTICAL == data) {
				//不匹配
				ret.setResultCode(Constant.UN_MATCH_CODE);
				ret.setResultBody(Constant.UN_MATCH);
				ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
				ret.setResultDesc(Constant.UN_MATCH);
			} else if(SjjhConstant.INTERFACE_RETURN_SUCCESS.equals(code+"")
					&& SjjhConstant.NO_FIND  ==  data) {
				//未找到
				ret.setResultCode(Constant.UN_FIND_NUM_CODE);
				ret.setResultBody(Constant.UN_FIND_NUM);
				ret.setResultDesc(Constant.UN_FIND_NUM);
			} else {
				//其他错误
				ret.setResultCode(Constant.OTHER_ERROR_CODE);
				ret.setResultBody(Constant.OTHER_ERROR);
				ret.setResultDesc(Constant.OTHER_ERROR);
			}
    	}

    	return ret;
    }

    /**
     * 手机号参数校验
     * @param mobile
     * @return
     */
    private ChannelTypeHandleResponseObject returnMobileCheckPara(
    		ChannelTypeHandleResponseObject ret,String mobile,String returnType) {
    	if(StringUtils.isBlank(mobile) ||
				!PatternTools.checkResult(Constant.PATTERN_MOBILE_REGEX, mobile)) {
	    	ret.setCode(Constant.SUCCESS);
	    	if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
	    		ret.setResultCode(Constant.MOBILE_FORMAT_ERROR_CODE);
	    		ret.setResultDesc(Constant.MOBILE_FORMAT_ERROR);
	    		ret.setResultBody(Constant.MOBILE_FORMAT_ERROR);
	    	} else {
	    		ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
	    		ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
	    		ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
	    	}
    	}

    	return ret;
    }

    /**
     * 运行商三要素参数校验
     * @param name
     * @param idCode
     * @param mobile
     * @return
     */
    private ChannelTypeHandleResponseObject returnISPThreeCheckPara(String name,
    		String idCode,String mobile,String returnType) {
    	ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();

    	if(StringUtils.isBlank(name) || !PatternTools.checkResult(Constant.PATTERN_CN_NAME_REGEX, name)) {
        	ret.setCode(Constant.SUCCESS);
        	if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
        		ret.setResultCode(Constant.NAME_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.NAME_FORMAT_ERROR);
        		ret.setResultBody(Constant.NAME_FORMAT_ERROR);
        	} else {
        		ret.setResultCode(Constant.JK_NAME_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.JK_NAME_FORMAT_ERROR);
        		ret.setResultBody(Constant.JK_NAME_FORMAT_ERROR);
        	}

        } else if(StringUtils.isBlank(idCode) || !PatternTools.checkResult(Constant.PATTERN_ID_NUMBER_REGEX, idCode)) {
        	ret.setCode(Constant.SUCCESS);
        	if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
        		ret.setResultCode(Constant.IDCODE_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.IDCODE_FORMAT_ERROR);
        		ret.setResultBody(Constant.IDCODE_FORMAT_ERROR);
        	} else {
        		ret.setResultCode(Constant.JK_IDCODE_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.JK_IDCODE_FORMAT_ERROR);
        		ret.setResultBody(Constant.JK_IDCODE_FORMAT_ERROR);
        	}

        }  else if(StringUtils.isBlank(mobile) || !PatternTools.checkResult(Constant.PATTERN_MOBILE_REGEX, mobile)) {
        	ret.setCode(Constant.SUCCESS);
        	if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
        		ret.setResultCode(Constant.MOBILE_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.MOBILE_FORMAT_ERROR);
        		ret.setResultBody(Constant.MOBILE_FORMAT_ERROR);
        	} else {
        		ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
        		ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
        	}

        }

    	return ret;
    }

    /**
     * 银行卡三要素参数校验
     * @param name
     * @param idCode
     * @param bankCode
     * @return
     */
    private ChannelTypeHandleResponseObject returnBankThreeCheckPara(
    		ChannelTypeHandleResponseObject ret,String name,
    		String idCode,String bankCode,String returnType) {
    	if(StringUtils.isBlank(name) || !PatternTools.checkResult(Constant.PATTERN_CN_NAME_REGEX, name)) {
        	ret.setCode(Constant.SUCCESS);
        	if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
        		ret.setResultCode(Constant.NAME_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.NAME_FORMAT_ERROR);
        		ret.setResultBody(Constant.NAME_FORMAT_ERROR);
        	} else {
        		ret.setResultCode(Constant.JK_NAME_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.JK_NAME_FORMAT_ERROR);
        		ret.setResultBody(Constant.JK_NAME_FORMAT_ERROR);
        	}

        } else if(StringUtils.isBlank(idCode) || !PatternTools.checkResult(Constant.PATTERN_ID_NUMBER_REGEX, idCode)) {
        	ret.setCode(Constant.SUCCESS);
        	if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
        		ret.setResultCode(Constant.IDCODE_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.IDCODE_FORMAT_ERROR);
        		ret.setResultBody(Constant.IDCODE_FORMAT_ERROR);
        	} else {
        		ret.setResultCode(Constant.JK_IDCODE_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.JK_IDCODE_FORMAT_ERROR);
        		ret.setResultBody(Constant.JK_IDCODE_FORMAT_ERROR);
        	}

        }  else if(StringUtils.isBlank(bankCode) || !PatternTools.checkResult(Constant.PATTERN_BANK_NUMBER_REGEX, bankCode)) {
        	ret.setCode(Constant.SUCCESS);
        	if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
        		ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
        	} else {
        		ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
        	}
        	ret.setResultDesc(BANK_CODE_ERROR);
        	ret.setResultBody(BANK_CODE_ERROR);
        }

    	return ret;
    }

    /**
     * 银行卡四要素参数校验
     * @param name
     * @param idCode
     * @param mobile
     * @param bankCode
     * @return
     */
    private ChannelTypeHandleResponseObject returnBankFourCheckPara(
    		ChannelTypeHandleResponseObject ret,String name,String idCode,
    		String mobile,String bankCode,String returnType) {
    	if(StringUtils.isBlank(name) || !PatternTools.checkResult(Constant.PATTERN_CN_NAME_REGEX, name)) {
        	ret.setCode(Constant.SUCCESS);
        	if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
        		ret.setResultCode(Constant.NAME_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.NAME_FORMAT_ERROR);
        		ret.setResultBody(Constant.NAME_FORMAT_ERROR);
        	} else {
        		ret.setResultCode(Constant.JK_NAME_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.JK_NAME_FORMAT_ERROR);
        		ret.setResultBody(Constant.JK_NAME_FORMAT_ERROR);
        	}

        } else if(StringUtils.isBlank(mobile) || !PatternTools.checkResult(Constant.PATTERN_MOBILE_REGEX, mobile)) {
        	ret.setCode(Constant.SUCCESS);
        	if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
        		ret.setResultCode(Constant.MOBILE_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.MOBILE_FORMAT_ERROR);
        		ret.setResultBody(Constant.MOBILE_FORMAT_ERROR);
        	} else {
        		ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
        		ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
        	}

        } else if(StringUtils.isBlank(idCode) || !PatternTools.checkResult(Constant.PATTERN_ID_NUMBER_REGEX, idCode)) {
        	ret.setCode(Constant.SUCCESS);
        	if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
        		ret.setResultCode(Constant.IDCODE_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.IDCODE_FORMAT_ERROR);
        		ret.setResultBody(Constant.IDCODE_FORMAT_ERROR);
        	} else {
        		ret.setResultCode(Constant.JK_IDCODE_FORMAT_ERROR_CODE);
        		ret.setResultDesc(Constant.JK_IDCODE_FORMAT_ERROR);
        		ret.setResultBody(Constant.JK_IDCODE_FORMAT_ERROR);
        	}

        }else if(StringUtils.isBlank(bankCode) || !PatternTools.checkResult(Constant.PATTERN_BANK_NUMBER_REGEX, bankCode)) {
        	ret.setCode(Constant.SUCCESS);
        	if(Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
        		ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
        	} else {
        		ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
        	}
        	ret.setResultDesc(BANK_CODE_ERROR);
        	ret.setResultBody(BANK_CODE_ERROR);
        }

    	return ret;
    }

	@Override
	public ChannelTypeHandleResponseObject scmDecodeThreeElement(HttpServletRequest request, String customBody, int outTime) {
		ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
		ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
		String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
		String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);

		if (StringUtils.isBlank(returnType)) {
			returnType = Constant.CUSTOMER_RETURN_ZW;
		}
		if (outTime <= 0) {
			outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
		}
		log.info("scmDecodeThreeElement---customBody={},outTime={}", customBody, outTime);

		try {
			ObjectMapper objectMapper = new ObjectMapper();
			DecodeThreeElementJsonResolveObject jsonResolveObject = objectMapper.readValue(customBody, DecodeThreeElementJsonResolveObject.class);
			if (!validateDecodeThreeElementParams(ret, returnType, jsonResolveObject)) {
				ret.setCode(Constant.SUCCESS);
				request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
				return ret;
			}

			DecodeThreeElementRequestObject.DecodeThreeElementRequestData dataObject = new DecodeThreeElementRequestObject.DecodeThreeElementRequestData();
			if (StringUtils.isNotBlank(jsonResolveObject.getIdCode())) {
				dataObject.setId_number(jsonResolveObject.getIdCode());
			}
			if (StringUtils.isNotBlank(jsonResolveObject.getMobile())) {
				dataObject.setMobile(jsonResolveObject.getMobile());
			}
			if (StringUtils.isNotBlank(jsonResolveObject.getName())) {
				dataObject.setName(jsonResolveObject.getName());
			}
            if (StringUtils.isBlank(jsonResolveObject.getEncrypt())) {
				dataObject.setEncrypt("MD5");
			} else {
				dataObject.setEncrypt(jsonResolveObject.getEncrypt());
			}

			DecodeThreeElementRequestObject requestObject = new DecodeThreeElementRequestObject();
			requestObject.setApi(decodeThreeElement);
			requestObject.setAppKey(appKey);
			requestObject.setAppSecret(secretKey);
			requestObject.setData(dataObject);

			MediaType mediaType = MediaType.parse("application/json; charset=utf-8");
			RequestBody requestBody = RequestBody.create(mediaType, JSON.toJSONString(requestObject));
			Request okRequest = new Request.Builder()
					.post(requestBody)
					.url(jkxyUrl)
					.build();
			OkHttpClient client = new OkHttpClient.Builder()
					.connectTimeout(outTime, TimeUnit.MILLISECONDS)
					.readTimeout(outTime, TimeUnit.MILLISECONDS)
					.writeTimeout(outTime, TimeUnit.MILLISECONDS)
					.build();
			Response response = client.newCall(okRequest).execute();
			String responseContext = "";
			if (response.body() != null) {
				responseContext = response.body().string();
			}
			log.info("supplier10000005.scmDecodeThreeElement接口responseContext={}", responseContext);
            JSONObject responseObject = JSON.parseObject(responseContext);
			log.info("supplier10000005.scmDecodeThreeElement接口responseObject={}", responseObject);
			if (responseObject != null) {
				ret.setCode(Constant.SUCCESS);
				setDecodeThreeElementResponse(ret, returnType, responseObject);
				upstreamCode = String.valueOf(responseObject.get("code"));
				response.close();
			} else {
				ret.setCode(Constant.FAIL);
			}
		} catch (SocketTimeoutException ste) {
			ErrorUtils.captureException(ste);
			log.info("supplier10000005.scmDecodeThreeElement接口SocketTimeoutException={}", ste);
			ret.setCode(Constant.REQUEST_TIMEOUT);
		} catch(UnrecognizedPropertyException upe) {
            log.info("三传木三要素解密接口-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
                ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            } else {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
            ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
        } catch (Exception ioe) {
			ErrorUtils.captureException(ioe);
			log.info("supplier10000005.scmDecodeThreeElement接口Exception={}", ioe);
			ret.setCode(Constant.FAIL);
		}

		//上游返回码
		request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
		return ret;
	}

	private void setDecodeThreeElementResponse(ChannelTypeHandleResponseObject ret, String returnType, JSONObject responseObject) {
    	String code = responseObject.get("code").toString();
    	String data = responseObject.get("data").toString();

    	boolean isCharge = code != null
				&& data != null
				&& code.equals(SjjhConstant.INTERFACE_RETURN_SUCCESS)
				&& data.equals(String.valueOf(SjjhConstant.INTERFACE_QUERY_IDENTICAL));
		if (isCharge) {
			ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
		}

		if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
			if (code.equals(SjjhConstant.INTERFACE_RETURN_SUCCESS) && data.equals(String.valueOf(SjjhConstant.INTERFACE_QUERY_IDENTICAL))) {
				// 查询成功，返回结果
				ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
				ret.setResultBody(getDecodeResult(JSON.parseObject(JSON.toJSONString(responseObject.get("msg")))));
				ret.setResultDesc(SjjhConstant.RESPONSE_TEXT_SUCCESS);
			} else if (code.equals(SjjhConstant.INTERFACE_RETURN_SUCCESS) && data.equals(String.valueOf(SjjhConstant.NO_FIND))) {
				// 查询成功，查无结果
				ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
				ret.setResultBody(Constant.UN_FIND_NUM);
				ret.setResultDesc(Constant.UN_FIND_NUM);
			} else if (code.equals(SjjhConstant.RESPONSE_CODE_1010) || code.equals(SjjhConstant.RESPONSE_CODE_1020)) {
				// 参数错误
				ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
				ret.setResultBody(Constant.INVALID_PARAMETER);
				ret.setResultDesc(Constant.INVALID_PARAMETER);
			} else {
				// 查询错误
				ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
				ret.setResultBody(Constant.OTHER_ERROR);
				ret.setResultDesc(Constant.OTHER_ERROR);
			}
		} else {
			if (code.equals(SjjhConstant.INTERFACE_RETURN_SUCCESS) && data.equals(String.valueOf(SjjhConstant.INTERFACE_QUERY_IDENTICAL))) {
				// 查询成功，返回结果
				ret.setResultCode(Constant.MATCH_CODE);
				ret.setResultBody(getDecodeResult(JSON.parseObject(JSON.toJSONString(responseObject.get("msg")))));
				ret.setResultDesc(SjjhConstant.RESPONSE_TEXT_SUCCESS);
			} else if (code.equals(SjjhConstant.INTERFACE_RETURN_SUCCESS) && data.equals(String.valueOf(SjjhConstant.NO_FIND))) {
				// 查询成功，查无结果
				ret.setResultCode(Constant.UN_FIND_NUM_CODE);
				ret.setResultBody(Constant.UN_FIND_NUM);
				ret.setResultDesc(Constant.UN_FIND_NUM);
			} else if (code.equals(SjjhConstant.RESPONSE_CODE_1010) || code.equals(SjjhConstant.RESPONSE_CODE_1020)) {
				// 参数错误
				ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
				ret.setResultBody(Constant.INVALID_PARAMETER);
				ret.setResultDesc(Constant.INVALID_PARAMETER);
			} else {
				// 查询错误
				ret.setResultCode(Constant.OTHER_ERROR_CODE);
				ret.setResultBody(Constant.OTHER_ERROR);
				ret.setResultDesc(Constant.OTHER_ERROR);
			}
		}
	}

	private void setDecodeIdCodeResponse(ChannelTypeHandleResponseObject ret, String returnType, JSONObject responseObject, String name) {
		String code = responseObject.get("code").toString();
		String data = responseObject.get("data").toString();

		boolean isCharge = code != null
				&& data != null
				&& code.equals(SjjhConstant.INTERFACE_RETURN_SUCCESS)
				&& data.equals(String.valueOf(SjjhConstant.INTERFACE_QUERY_IDENTICAL));
		if (isCharge) {
			ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
		}

		if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
			if (code.equals(SjjhConstant.INTERFACE_RETURN_SUCCESS) && data.equals(String.valueOf(SjjhConstant.INTERFACE_QUERY_IDENTICAL))) {
				// 查询成功，返回结果
				ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
				ret.setResultBody(getDecodeIdCodeResult(JSON.parseObject(JSON.toJSONString(responseObject.get("msg"))), name));
				ret.setResultDesc(SjjhConstant.RESPONSE_TEXT_SUCCESS);
			} else if (code.equals(SjjhConstant.INTERFACE_RETURN_SUCCESS) && data.equals(String.valueOf(SjjhConstant.NO_FIND))) {
				// 查询成功，查无结果
				ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
				ret.setResultBody(Constant.UN_FIND_NUM);
				ret.setResultDesc(Constant.UN_FIND_NUM);
			} else if (code.equals(SjjhConstant.RESPONSE_CODE_1010) || code.equals(SjjhConstant.RESPONSE_CODE_1020)) {
				// 参数错误
				ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
				ret.setResultBody(Constant.INVALID_PARAMETER);
				ret.setResultDesc(Constant.INVALID_PARAMETER);
			} else {
				// 查询错误
				ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
				ret.setResultBody(Constant.OTHER_ERROR);
				ret.setResultDesc(Constant.OTHER_ERROR);
			}
		} else {
			if (code.equals(SjjhConstant.INTERFACE_RETURN_SUCCESS) && data.equals(String.valueOf(SjjhConstant.INTERFACE_QUERY_IDENTICAL))) {
				// 查询成功，返回结果
				ret.setResultCode(Constant.MATCH_CODE);
				ret.setResultBody(getDecodeIdCodeResult(JSON.parseObject(JSON.toJSONString(responseObject.get("msg"))), name));
				ret.setResultDesc(SjjhConstant.RESPONSE_TEXT_SUCCESS);
			} else if (code.equals(SjjhConstant.INTERFACE_RETURN_SUCCESS) && data.equals(String.valueOf(SjjhConstant.NO_FIND))) {
				// 查询成功，查无结果
				ret.setResultCode(Constant.UN_FIND_NUM_CODE);
				ret.setResultBody(Constant.UN_FIND_NUM);
				ret.setResultDesc(Constant.UN_FIND_NUM);
			} else if (code.equals(SjjhConstant.RESPONSE_CODE_1010) || code.equals(SjjhConstant.RESPONSE_CODE_1020)) {
				// 参数错误
				ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
				ret.setResultBody(Constant.INVALID_PARAMETER);
				ret.setResultDesc(Constant.INVALID_PARAMETER);
			} else {
				// 查询错误
				ret.setResultCode(Constant.OTHER_ERROR_CODE);
				ret.setResultBody(Constant.OTHER_ERROR);
				ret.setResultDesc(Constant.OTHER_ERROR);
			}
		}
	}

	private String getDecodeResult(JSONObject decodeResult) {
		JSONObject result = new JSONObject();
		if (decodeResult.get("name") != null) {
			result.put("name", decodeResult.get("name"));
		}
		if (decodeResult.get("idcard") != null) {
			result.put("idCode", decodeResult.get("idcard"));
		}
		if (decodeResult.get("mobile") != null) {
			result.put("mobile", decodeResult.get("mobile"));
		}
		return result.toJSONString();
	}

	private String getDecodeIdCodeResult(JSONObject decodeResult, String name) {
		JSONObject result = new JSONObject();
		result.put("name", name);
		if (decodeResult.get("idcard") != null) {
			result.put("idCode", decodeResult.get("idcard"));
		}
		return result.toJSONString();
	}

	private boolean validateDecodeThreeElementParams(ChannelTypeHandleResponseObject ret, String returnType, DecodeThreeElementJsonResolveObject jsonResolveObject) {
		if (StringUtils.isAllBlank(jsonResolveObject.getIdCode(), jsonResolveObject.getMobile(), jsonResolveObject.getName())) {
			if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
				ret.setResultBody(Constant.INVALID_PARAMETER);
				ret.setResultDesc(Constant.INVALID_PARAMETER);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
				ret.setResultBody(Constant.INVALID_PARAMETER);
				ret.setResultDesc(Constant.INVALID_PARAMETER);
			}
			return false;
		} else {
    		return true;
		}
	}

	private boolean validateParamNullValue(Object jsonResolveObject) {
		ValidatorFactory vf = Validation.buildDefaultValidatorFactory();
		Validator validator = vf.getValidator();
		Set<ConstraintViolation<Object>> set = validator.validate(jsonResolveObject);
		for (ConstraintViolation<Object> con : set) {
			if (StringUtils.isNotBlank(con.getMessage())) {
				return false;
			}
		}
		return true;
	}

	@Override
	public ChannelTypeHandleResponseObject scmCTCCThreeElementInfo(HttpServletRequest request, String customBody, int outTime) {
		ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
		ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
		String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
		String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);

		if (StringUtils.isBlank(returnType)) {
			returnType = Constant.CUSTOMER_RETURN_ZW;
		}
		if (outTime <= 0) {
			outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
		}
		log.info("scmCTCCThreeElementInfo---customBody={},outTime={}", customBody, outTime);

		try {
			ObjectMapper objectMapper = new ObjectMapper();
			SCMIdCardCheckRequestObject jsonResolveObject = objectMapper.readValue(customBody,
					SCMIdCardCheckRequestObject.class);

			if (!validateThreeElementParams(ret, returnType, jsonResolveObject)) {
				ret.setCode(Constant.SUCCESS);
				request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
				return ret;
			}

			SCMIdCardCheckRequestChildObject dataObject = new SCMIdCardCheckRequestChildObject();
			dataObject.setId_number(jsonResolveObject.getIdCode());
			dataObject.setMobile(jsonResolveObject.getMobile());
			dataObject.setName(jsonResolveObject.getName());

			RequestJsonObject requestObject = new RequestJsonObject();
			requestObject.setApi(ctccDetail);
			requestObject.setAppKey(appKey);
			requestObject.setAppSecret(secretKey);
			requestObject.setData(dataObject);

			MediaType mediaType = MediaType.parse("application/json; charset=utf-8");
			RequestBody requestBody = RequestBody.create(mediaType, JSON.toJSONString(requestObject));
			Request okRequest = new Request.Builder()
					.post(requestBody)
					.url(jkxyUrl)
					.build();
			OkHttpClient client = new OkHttpClient.Builder()
					.connectTimeout(outTime, TimeUnit.MILLISECONDS)
					.readTimeout(outTime, TimeUnit.MILLISECONDS)
					.writeTimeout(outTime, TimeUnit.MILLISECONDS)
					.build();
			Response response = client.newCall(okRequest).execute();
			String responseContext = "";
			if (response.body() != null) {
				responseContext = response.body().string();
			}
			log.info("supplier10000005.scmCTCCThreeElementInfo接口responseContext={}", responseContext);
			JSONObject responseObject = JSON.parseObject(responseContext);
			log.info("supplier10000005.scmCTCCThreeElementInfo接口responseObject={}", responseObject);
			if (responseObject != null) {
				ret.setCode(Constant.SUCCESS);
				setCTCCThreeElementInfoResponse(ret, returnType, responseObject);
				upstreamCode = String.valueOf(responseObject.get("code"));
				response.close();
			} else {
				ret.setCode(Constant.FAIL);
			}
		} catch (SocketTimeoutException ste) {
			ErrorUtils.captureException(ste);
			log.info("supplier10000005.scmCTCCThreeElementInfo接口SocketTimeoutException={}", ste);
			ret.setCode(Constant.REQUEST_TIMEOUT);
		} catch(UnrecognizedPropertyException upe) {
			log.info("三传木电信三要素详版-UnrecognizedPropertyException：{}", upe);
			ErrorUtils.captureException(upe);
			ret.setCode(Constant.SUCCESS);
			ret.setIsCharge(Constant.IS_NOT_CHARGE);
			/**参数错误*/
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
				ret.setResultCode(Constant.JK_RETURN_CODE_9909);
			} else {
				ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
			}
			ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
			ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
			return ret;
		} catch (Exception ioe) {
			ErrorUtils.captureException(ioe);
			log.info("supplier10000005.scmCTCCThreeElementInfo接口Exception={}", ioe);
			ret.setCode(Constant.FAIL);
		}

		//上游返回码
		request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
		return ret;
	}

	private boolean validateThreeElementParams(ChannelTypeHandleResponseObject ret, String returnType, SCMIdCardCheckRequestObject jsonResolveObject) {
		if (StringUtils.isBlank(jsonResolveObject.getIdCode())
				|| !PatternTools.checkResult(Constant.PATTERN_ID_NUMBER_REGEX, jsonResolveObject.getIdCode())) {
			if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.IDCODE_FORMAT_ERROR_CODE);
				ret.setResultDesc(Constant.IDCODE_FORMAT_ERROR);
				ret.setResultBody(Constant.IDCODE_FORMAT_ERROR);
			} else {
				ret.setResultCode(Constant.JK_IDCODE_FORMAT_ERROR_CODE);
				ret.setResultDesc(Constant.JK_IDCODE_FORMAT_ERROR);
				ret.setResultBody(Constant.JK_IDCODE_FORMAT_ERROR);
			}
			return false;
		} else if (StringUtils.isBlank(jsonResolveObject.getMobile())
				|| !PatternTools.checkResult(Constant.PATTERN_MOBILE_REGEX, jsonResolveObject.getMobile())) {
			if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.MOBILE_FORMAT_ERROR_CODE);
				ret.setResultDesc(Constant.MOBILE_FORMAT_ERROR);
				ret.setResultBody(Constant.MOBILE_FORMAT_ERROR);
			} else {
				ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
				ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
				ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
			}
			return false;
		} else if (StringUtils.isBlank(jsonResolveObject.getMobile())
				|| !PatternTools.checkResult(Constant.PATTERN_CTCC_MOBILE_REGEX, jsonResolveObject.getMobile())) {
			if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.PARAGRAPH_NUMBER_UNMATCH_CODE);
				ret.setResultDesc(Constant.RETURN_MESSAGE_63);
				ret.setResultBody(Constant.RETURN_MESSAGE_63);
			} else {
				ret.setResultCode(Constant.JK_RETURN_CODE_9903);
				ret.setResultDesc(Constant.RETURN_MESSAGE_63);
				ret.setResultBody(Constant.RETURN_MESSAGE_63);
			}
			return false;
		} else if (StringUtils.isBlank(jsonResolveObject.getName())
				|| !PatternTools.checkResult(Constant.PATTERN_CN_NAME_REGEX, jsonResolveObject.getName())) {
			if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
				ret.setResultCode(Constant.NAME_FORMAT_ERROR_CODE);
				ret.setResultDesc(Constant.NAME_FORMAT_ERROR);
				ret.setResultBody(Constant.NAME_FORMAT_ERROR);
			} else {
				ret.setResultCode(Constant.JK_NAME_FORMAT_ERROR_CODE);
				ret.setResultDesc(Constant.JK_NAME_FORMAT_ERROR);
				ret.setResultBody(Constant.JK_NAME_FORMAT_ERROR);
			}
			return false;
		} else {
			return true;
		}
	}

	private void setCTCCThreeElementInfoResponse(ChannelTypeHandleResponseObject ret, String returnType, JSONObject responseObject) {
		String code = responseObject.get("code").toString();
		String data = responseObject.get("data").toString();
    	boolean isCharge = code != null
				&& data != null
				&& code.equals(SjjhConstant.INTERFACE_RETURN_SUCCESS)
				&& data.equals(String.valueOf(SjjhConstant.INTERFACE_QUERY_IDENTICAL))
				&& data.equals(String.valueOf(SjjhConstant.INTERFACE_QUERY_NO_IDENTICAL));
		if (isCharge) {
			ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
		}

		if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
			if (code.equals(SjjhConstant.INTERFACE_RETURN_SUCCESS) && data.equals(String.valueOf(SjjhConstant.INTERFACE_QUERY_IDENTICAL))) {
				// 查询一致
				ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
				ret.setResultBody(Constant.MATCH);
				ret.setResultDesc(Constant.MATCH);
			} else if (code.equals(SjjhConstant.INTERFACE_RETURN_SUCCESS)
					&& data.equals(String.valueOf(SjjhConstant.INTERFACE_QUERY_NO_IDENTICAL))) {
				JSONObject msg = JSON.parseObject(JSON.toJSONString(responseObject.get("msg")));
				if (msg.get("data").toString().equals(SjjhConstant.CTCC_DATA_2)) {
					// 手机号已实名，但是身份证和姓名均与实名信息不一致
					ret.setResultCode(Constant.JK_RETURN_CODE_1181);
					ret.setResultBody(Constant.RETURN_MESSAGE_121);
					ret.setResultDesc(Constant.RETURN_MESSAGE_121);
				} else if (msg.get("data").toString().equals(SjjhConstant.CTCC_DATA_3)) {
					// 手机号已实名，手机号和证件号一致，姓名不一致
					ret.setResultCode(Constant.JK_RETURN_CODE_1182);
					ret.setResultBody(Constant.RETURN_MESSAGE_122);
					ret.setResultDesc(Constant.RETURN_MESSAGE_122);
				} else {
					// 手机号已实名，手机号和姓名一致，身份证不一致
					ret.setResultCode(Constant.JK_RETURN_CODE_1183);
					ret.setResultBody(Constant.RETURN_MESSAGE_123);
					ret.setResultDesc(Constant.RETURN_MESSAGE_123);
				}

			} else if (code.equals(SjjhConstant.INTERFACE_RETURN_SUCCESS) && data.equals(String.valueOf(SjjhConstant.NO_FIND))) {
				// 查询成功，查无结果
				ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
				ret.setResultBody(Constant.UN_FIND_NUM);
				ret.setResultDesc(Constant.UN_FIND_NUM);
			} else if (code.equals(SjjhConstant.RESPONSE_CODE_1010) || code.equals(SjjhConstant.RESPONSE_CODE_1020)) {
				// 参数错误
				ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
				ret.setResultBody(Constant.INVALID_PARAMETER);
				ret.setResultDesc(Constant.INVALID_PARAMETER);
			} else {
				// 查询错误
				ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
				ret.setResultBody(Constant.OTHER_ERROR);
				ret.setResultDesc(Constant.OTHER_ERROR);
			}
		} else {
			if (code.equals(SjjhConstant.INTERFACE_RETURN_SUCCESS) && data.equals(String.valueOf(SjjhConstant.INTERFACE_QUERY_IDENTICAL))) {
				// 查询一致
				ret.setResultCode(Constant.MATCH_CODE);
				ret.setResultBody(Constant.MATCH);
				ret.setResultDesc(Constant.MATCH);
			} else if (code.equals(SjjhConstant.INTERFACE_RETURN_SUCCESS)
					&& data.equals(String.valueOf(SjjhConstant.INTERFACE_QUERY_NO_IDENTICAL))) {
				JSONObject msg = JSON.parseObject(JSON.toJSONString(responseObject.get("msg")));
				if (msg.get("data").toString().equals(SjjhConstant.CTCC_DATA_2)) {
					// 手机号已实名，但是身份证和姓名均与实名信息不一致
					ret.setResultCode(Constant.ZW_RETURN_CODE_121);
					ret.setResultBody(Constant.RETURN_MESSAGE_121);
					ret.setResultDesc(Constant.RETURN_MESSAGE_121);
				} else if (msg.get("data").toString().equals(SjjhConstant.CTCC_DATA_3)) {
					// 手机号已实名，手机号和证件号一致，姓名不一致
					ret.setResultCode(Constant.ZW_RETURN_CODE_122);
					ret.setResultBody(Constant.RETURN_MESSAGE_122);
					ret.setResultDesc(Constant.RETURN_MESSAGE_122);
				} else {
					// 手机号已实名，手机号和姓名一致，身份证不一致
					ret.setResultCode(Constant.ZW_RETURN_CODE_123);
					ret.setResultBody(Constant.RETURN_MESSAGE_123);
					ret.setResultDesc(Constant.RETURN_MESSAGE_123);
				}
			} else if (code.equals(SjjhConstant.INTERFACE_RETURN_SUCCESS) && data.equals(String.valueOf(SjjhConstant.NO_FIND))) {
				// 查询成功，查无结果
				ret.setResultCode(Constant.UN_FIND_NUM_CODE);
				ret.setResultBody(Constant.UN_FIND_NUM);
				ret.setResultDesc(Constant.UN_FIND_NUM);
			} else if (code.equals(SjjhConstant.RESPONSE_CODE_1010) || code.equals(SjjhConstant.RESPONSE_CODE_1020)) {
				// 参数错误
				ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
				ret.setResultBody(Constant.INVALID_PARAMETER);
				ret.setResultDesc(Constant.INVALID_PARAMETER);
			} else {
				// 查询错误
				ret.setResultCode(Constant.OTHER_ERROR_CODE);
				ret.setResultBody(Constant.OTHER_ERROR);
				ret.setResultDesc(Constant.OTHER_ERROR);
			}
		}
	}

	@Override
	public ChannelTypeHandleResponseObject scmDecodeIdCode(HttpServletRequest request, String customBody, int outTime) {
		ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
		ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
		String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
		String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);

		if (StringUtils.isBlank(returnType)) {
			returnType = Constant.CUSTOMER_RETURN_ZW;
		}
		if (outTime <= 0) {
			outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
		}
		log.info("scmDecodeIdCode---customBody={},outTime={}", customBody, outTime);

		try {
			ObjectMapper objectMapper = new ObjectMapper();
			DecodeThreeElementJsonResolveObject jsonResolveObject = objectMapper.readValue(customBody, DecodeThreeElementJsonResolveObject.class);
			if (!validateDecodeThreeElementParams(ret, returnType, jsonResolveObject)) {
				ret.setCode(Constant.SUCCESS);
				request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
				return ret;
			}

			DecodeThreeElementRequestObject.DecodeThreeElementRequestData dataObject = new DecodeThreeElementRequestObject.DecodeThreeElementRequestData();
			if (StringUtils.isNotBlank(jsonResolveObject.getIdCode())) {
				dataObject.setId_number(jsonResolveObject.getIdCode());
			}
			if (StringUtils.isBlank(jsonResolveObject.getEncrypt())) {
				dataObject.setEncrypt("MD5");
			} else {
				dataObject.setEncrypt(jsonResolveObject.getEncrypt());
			}

			DecodeThreeElementRequestObject requestObject = new DecodeThreeElementRequestObject();
			requestObject.setApi(decodeThreeElement);
			requestObject.setAppKey(appKey);
			requestObject.setAppSecret(secretKey);
			requestObject.setData(dataObject);

			MediaType mediaType = MediaType.parse("application/json; charset=utf-8");
			RequestBody requestBody = RequestBody.create(mediaType, JSON.toJSONString(requestObject));
			Request okRequest = new Request.Builder()
					.post(requestBody)
					.url(jkxyUrl)
					.build();
			OkHttpClient client = new OkHttpClient.Builder()
					.connectTimeout(outTime, TimeUnit.MILLISECONDS)
					.readTimeout(outTime, TimeUnit.MILLISECONDS)
					.writeTimeout(outTime, TimeUnit.MILLISECONDS)
					.build();
			Response response = client.newCall(okRequest).execute();
			String responseContext = "";
			if (response.body() != null) {
				responseContext = response.body().string();
			}
			log.info("supplier10000005.scmDecodeIdCode接口responseContext={}", responseContext);
			JSONObject responseObject = JSON.parseObject(responseContext);
			log.info("supplier10000005.scmDecodeIdCode接口responseObject={}", responseObject);
			if (responseObject != null) {
				ret.setCode(Constant.SUCCESS);
				setDecodeIdCodeResponse(ret, returnType, responseObject, jsonResolveObject.getName());
				upstreamCode = String.valueOf(responseObject.get("code"));
				response.close();
			} else {
				ret.setCode(Constant.FAIL);
			}
		} catch (SocketTimeoutException ste) {
			ErrorUtils.captureException(ste);
			log.info("supplier10000005.scmDecodeIdCode接口SocketTimeoutException={}", ste);
			ret.setCode(Constant.REQUEST_TIMEOUT);
		} catch(UnrecognizedPropertyException upe) {
			log.info("三传木身份证解密接口-UnrecognizedPropertyException：{}", upe);
			ErrorUtils.captureException(upe);
			ret.setCode(Constant.SUCCESS);
			ret.setIsCharge(Constant.IS_NOT_CHARGE);
			/**参数错误*/
			if(Constant.CUSTOMER_RETURN_JK.equals(returnType)){
				ret.setResultCode(Constant.JK_RETURN_CODE_9909);
			} else {
				ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
			}
			ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
			ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
			return ret;
		} catch (Exception ioe) {
			ErrorUtils.captureException(ioe);
			log.info("supplier10000005.scmDecodeIdCode接口Exception={}", ioe);
			ret.setCode(Constant.FAIL);
		}

		//上游返回码
		request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
		return ret;
	}
}
